minrpc
------

|Version| |License| |Python| |Build| |Coverage|

Minimalistic RPC utility.

Please do not use. This package is only used within cpymad and pytao.


.. |Build| image:: https://api.travis-ci.org/hibtc/minrpc.svg?branch=master
   :target: https://travis-ci.org/hibtc/minrpc
   :alt: Build Status

.. |Coverage| image:: https://coveralls.io/repos/hibtc/minrpc/badge.svg?branch=master
   :target: https://coveralls.io/r/hibtc/minrpc
   :alt: Coverage

.. |Version| image:: http://coldfix.de:8080/v/minrpc/badge.svg
   :target: https://pypi.python.org/pypi/minrpc/
   :alt: Latest Version

.. |License| image:: http://img.shields.io/badge/license-CC0,_Apache,_Non--Free-red.svg
   :target: https://github.com/hibtc/minrpc/blob/master/COPYING.GPLv3.txt
   :alt: License

.. |Python| image:: http://coldfix.de:8080/py_versions/minrpc/badge.svg
   :target: https://pypi.python.org/pypi/minrpc#downloads
   :alt: Supported Python versions
